CExpandable class

Inheritance

Constructors

CExpandable({PlatformStyle? platformStyle, Widget header(bool expanded)?, Widget? child, Widget? collapsedChild, bool showIcon = true, Curve? curve, Duration? duration, Alignment childAlignment = Alignment.topCenter, ValueChanged<bool>? onExpandChanged, bool initialExpanded = false, Widget? icon, bool useButton = false, String? buttonExpandedText, String? buttonCollapsedText, Color? buttonColor, BtnSize? buttonSize, double buttonMinHeight = 44, ExpandPosition expandPosition = ExpandPosition.bottom, bool showDivider = false, EdgeInsetsGeometry? arrowPadding, CrossAxisAlignment arrowAlignment = CrossAxisAlignment.center, double arrowSize = 20, Widget? extraTop, Widget? extraBottom, Key? key})
const

Properties

arrowAlignment CrossAxisAlignment
final
arrowPadding EdgeInsetsGeometry?
final
arrowSize double
final
buttonCollapsedText String?
final
buttonColor Color?
final
buttonExpandedText String?
final
buttonMinHeight double
final
buttonSize BtnSize?
final
child Widget?
Show when expanded
final
childAlignment Alignment
For crossfading children to align child & collapsedChild
final
collapsedChild Widget?
Show when not expanded
final
curve Curve?
final
duration Duration?
final
expandPosition ExpandPosition
final
extraBottom Widget?
final
extraTop Widget?
final
hashCode int
The hash code for this object.
no setterinherited
The bar at the top for click
final
icon Widget?
Use a custom icon instead of the arrow, this icon will rotate 180 degree
final
initialExpanded bool
Is is initially expanded?
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onExpandChanged ValueChanged<bool>?
Triggered when expansion changed
final
platformStyle PlatformStyle?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showDivider bool
final
showIcon bool
final
useButton bool
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<CExpandable>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited