CListTileSkeletonOption class
Constructors
- CListTileSkeletonOption({double titleWidth = 0.4, double subtitleWidth = 0.6, Size avatarSize = const Size(36, 36), bool showAvatar = true, bool showTitle = true, bool showContent = true, BorderRadiusGeometry? avatarBorderRadius, BoxShape avatarBoxShape = BoxShape.circle})
-
const
Properties
- avatarBorderRadius → BorderRadiusGeometry?
-
final
- avatarBoxShape → BoxShape
-
final
- avatarSize → Size
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showAvatar → bool
-
final
- showContent → bool
-
final
- showTitle → bool
-
final
- subtitleWidth → double
-
final
- titleWidth → double
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited